@@ -1,4 +1,5 @@
 import ast
+from contextlib import nullcontext
 import functools
 from typing import Any, Callable, Optional
 
@@ -33,6 +34,13 @@ def start_span(span_name:str, trace_id_req, span_id_req):
     span = trace.get_tracer(__name__).start_as_current_span(str(span_name), context=ctx)
     return span
 
+def get_span_from_ctx(trace_ctx, name):
+
+    if not __EXPORT_TRACES:
+        return nullcontext()
+
+    return start_span(name, trace_ctx.get("x-trace-id", None), trace_ctx.get("x-span-id", None))
+
 def __configure_fastapi(tracer_provider, fastapi_app=None):
     if not fastapi_app:
         return
